package types

import (
	"time"

	"gorm.io/gorm"
)

type BarcodeStatus uint16

type LoadingBed uint8

const (
	ATA12 LoadingBed = iota + 1
	ATA345
	ALL
)

var MapLoadingBed = map[string]LoadingBed{
	"1": ATA12,
	"2": ATA345,
	"3": ALL,
}

var MapFormatBed = map[LoadingBed]string{
	ATA12:  "ATA12",
	ATA345: "ATA345",
	ALL:    "TODOS",
}

var MapQueryBed = map[LoadingBed]string{
	ATA12:  "940",
	ATA345: "945",
}

type Barcode struct {
	Barcode    string `gorm:"primaryKey"`
	LoadingBed LoadingBed
	CreatedAt  time.Time      `gorm:"->;<-:create" json:"createdat,omitempty"`
	UpdatedAt  time.Time      `json:"updatedat,omitempty"`
	DeletedAt  gorm.DeletedAt `gorm:"index" json:"deletedat,omitempty"`
}

func (b *Barcode) FormatLoadingBed() string {
	return MapFormatBed[b.LoadingBed]
}

func (b *Barcode) FormatCreatedAt() string {
	return b.CreatedAt.Format("02/01/2006 15:04:05")
}

func (b *Barcode) FormatUpdateAt() string {
	return b.UpdatedAt.Format("02/01/2006 15:04:05")
}
